Headers

Struct Headers 

pub struct Headers(/* private fields */);
Wrapper around HashMap<Ascii, String> with additional functionality for parsing HTTP headers

Example

use http_req::response::Headers;

let mut headers = Headers::new();
headers.insert("Connection", "Close");

assert_eq!(headers.get("Connection"), Some(&"Close".to_string()))

Implementations

Source

impl Headers

pub fn new() -> Headers

Creates an empty Headers.

The headers are initially created with a capacity of 0, so they will not allocate until it is first inserted into.

Examples
use http_req::response::Headers;

let mut headers = Headers::new();
Examples found in repository?
examples/add_headers.rs (line 14)
8fn main() {
9    let mut writer = Vec::new();
10    let uri = Uri::try_from("http://eu.httpbin.org/get?msg=WasmEdge").unwrap();
11    // let uri = Uri::try_from("https://httpbin.org/get").unwrap(); // uncomment the line for https request
12
13    // add headers to the request
14    let mut headers = Headers::new();
15    headers.insert("Accept-Charset", "utf-8");
16    headers.insert("Accept-Language", "en-US");
17    headers.insert("Host", "rust-lang.org");
18    headers.insert("Connection", "Close");
19
20    Request::new(&uri)
21        .headers(headers)
22        .send(&mut writer)
23        .unwrap();
24
25    println!("{}", String::from_utf8_lossy(&writer));
26
27    // set version
28    Request::new(&uri)
29        .version(HttpVersion::Http10)
30        .send(&mut writer)
31        .unwrap();
32
33    println!("{}", String::from_utf8_lossy(&writer));
34}
pub fn with_capacity(capacity: usize) -> Headers

Creates empty Headers with the specified capacity.

The headers will be able to hold at least capacity elements without reallocating. If capacity is 0, the headers will not allocate.

Examples
use http_req::response::Headers;

let mut headers = Headers::with_capacity(200);
pub fn iter(&self) -> Iter<'_, Ascii<String>, String>

An iterator visiting all key-value pairs in arbitrary order. The iterator’s element type is (&Ascii, &String).

Examples
use http_req::response::Headers;

let mut headers = Headers::new();
headers.insert("Accept-Charset", "utf-8");
headers.insert("Accept-Language", "en-US");
headers.insert("Connection", "Close");

let mut iterator = headers.iter();
pub fn get<T: ToString + ?Sized>(&self, k: &T) -> Option<&String>

Returns a reference to the value corresponding to the key.

Examples
use http_req::response::Headers;

let mut headers = Headers::new();
headers.insert("Accept-Charset", "utf-8");

assert_eq!(headers.get("Accept-Charset"), Some(&"utf-8".to_string()))
pub fn insert<T, U>(&mut self, key: &T, val: &U) -> Option<String>
where T: ToString + ?Sized, U: ToString + ?Sized,

Inserts a key-value pair into the headers.

If the headers did not have this key present, None is returned.

If the headers did have this key present, the value is updated, and the old value is returned. The key is not updated, though; this matters for types that can be == without being identical.

Examples
use http_req::response::Headers;

let mut headers = Headers::new();
headers.insert("Accept-Language", "en-US");
Examples found in repository?
examples/add_headers.rs (line 15)
8fn main() {
9    let mut writer = Vec::new();
10    let uri = Uri::try_from("http://eu.httpbin.org/get?msg=WasmEdge").unwrap();
11    // let uri = Uri::try_from("https://httpbin.org/get").unwrap(); // uncomment the line for https request
12
13    // add headers to the request
14    let mut headers = Headers::new();
15    headers.insert("Accept-Charset", "utf-8");
16    headers.insert("Accept-Language", "en-US");
17    headers.insert("Host", "rust-lang.org");
18    headers.insert("Connection", "Close");
19
20    Request::new(&uri)
21        .headers(headers)
22        .send(&mut writer)
23        .unwrap();
24
25    println!("{}", String::from_utf8_lossy(&writer));
26
27    // set version
28    Request::new(&uri)
29        .version(HttpVersion::Http10)
30        .send(&mut writer)
31        .unwrap();
32
33    println!("{}", String::from_utf8_lossy(&writer));
34}
pub fn default_http(uri: &Uri<'_>) -> Headers

Creates default headers for a HTTP request

Examples
use http_req::{response::Headers, uri::Uri};
use std::convert::TryFrom;

let uri: Uri = Uri::try_from("https://www.rust-lang.org/learn").unwrap();
let headers = Headers::default_http(&uri);