Module stream

TCP stream

Enums

Stream
Wrapper around TCP stream for HTTP and HTTPS protocols. Allows to perform common operations on underlying stream.

Traits

ThreadReceive
Trait that allows to receive data from receivers
ThreadSend
Trait that allows to send data from readers to other threads

Functions

connect_with_timeout
Connects to the target host with a specified timeout.
execute_with_deadline
Executes a function in a loop until operation is completed or deadline is exceeded.
read_head
Reads the head of HTTP response from reader.