TCP stream
Enums
- Stream
- Wrapper around TCP stream for HTTP and HTTPS protocols. Allows to perform common operations on underlying stream.
Traits
- Thread
Receive - Trait that allows to receive data from receivers
- Thread
Send - Trait that allows to send data from readers to other threads
Functions
- connect_
with_ timeout - Connects to the target host with a specified timeout.
- execute_
with_ deadline - Executes a function in a loop until operation is completed or deadline is exceeded.
- read_
head - Reads the head of HTTP response from
reader.