TCP stream
Enums
- Wrapper around TCP stream for HTTP and HTTPS protocols. Allows to perform common operations on underlying stream.
Traits
- Trait that allows to receive data from receivers
- Trait that allows to send data from readers to other threads
Functions
- Connects to the target host with a specified timeout.
- Exexcutes a function in a loop until operation is completed or deadline is exceeded.
- Reads the head of HTTP response from
reader.